==> kvision-server-ktor-js-4.1.0.jar: kvision-kvision-server-ktor-jsLegacy.js <==
(function (root, factory) {
  if (typeof define === 'function' && define.amd)
    define(['exports', 'kotlin', 'kvision-kvision-common-remote-jsLegacy'], factory);
  else if (typeof exports === 'object')
    factory(module.exports, require('kotlin'), require('kvision-kvision-common-remote-jsLegacy'));
  else {
    if (typeof kotlin === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-server-ktor-jsLegacy'. Its dependency 'kotlin' was not found. Please, check whether 'kotlin' is loaded prior to 'kvision-kvision-server-ktor-jsLegacy'.");
    }if (typeof this['kvision-kvision-common-remote-jsLegacy'] === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-server-ktor-jsLegacy'. Its dependency 'kvision-kvision-common-remote-jsLegacy' was not found. Please, check whether 'kvision-kvision-common-remote-jsLegacy' is loaded prior to 'kvision-kvision-server-ktor-jsLegacy'.");
    }root['kvision-kvision-server-ktor-jsLegacy'] = factory(typeof this['kvision-kvision-server-ktor-jsLegacy'] === 'undefined' ? {} : this['kvision-kvision-server-ktor-jsLegacy'], kotlin, this['kvision-kvision-common-remote-jsLegacy']);
  }
}(this, function (_, Kotlin, $module$kvision_kvision_common_remote_jsLegacy) {
  'use strict';
  var $$importsForInline$$ = _.$$importsForInline$$ || (_.$$importsForInline$$ = {});
  var defineInlineFunction = Kotlin.defineInlineFunction;
  var wrapFunction = Kotlin.wrapFunction;
  var Kind_CLASS = Kotlin.Kind.CLASS;
  var KVServiceMgr = $module$kvision_kvision_common_remote_jsLegacy.io.kvision.remote.KVServiceMgr;
  var LinkedHashMap_init = Kotlin.kotlin.collections.LinkedHashMap_init_q3lmfv$;
  function KVServiceManager(serviceClass) {
    this.calls = LinkedHashMap_init();
    this.counter = 0;
  }
  KVServiceManager.prototype.bind_n9wdgo$ = defineInlineFunction('kvision-kvision-server-ktor-jsLegacy.io.kvision.remote.KVServiceManager.bind_n9wdgo$', wrapFunction(function () {
    var HttpMethod = _.$$importsForInline$$['kvision-kvision-common-remote-jsLegacy'].io.kvision.remote.HttpMethod;
    var toString = Kotlin.toString;
    var Pair_init = Kotlin.kotlin.Pair;
    var KFunction = Kotlin.kotlin.reflect.KFunction;
    var Regex_init = Kotlin.kotlin.text.Regex_init_61zpoe$;
    return function (RET_0, isRET, function_0, method, route) {
      if (method === void 0)
        method = HttpMethod.POST;
      if (route === void 0)
        route = null;
      var tmp$, tmp$_0, tmp$_1, tmp$_2, tmp$_3, tmp$_4;
      var routeDef = route != null ? route : 'route' + toString(Kotlin.getKClassFromExpression(this).simpleName) + (tmp$ = this.counter, this.counter = tmp$ + 1 | 0, tmp$);
      tmp$_4 = this.calls;
      var tmp$_5;
      if ((tmp$_2 = (tmp$_1 = Kotlin.isType(tmp$_0 = function_0, KFunction) ? tmp$_0 : null) != null ? tmp$_1.callableName : null) != null)
        tmp$_5 = tmp$_2;
      else {
        var tmp$_6 = function_0.toString();
        tmp$_5 = Regex_init('\\s').replace_x2uqeu$(tmp$_6, '');
      }
      tmp$_3 = tmp$_5;
      var value = new Pair_init('/kv/' + routeDef, method);
      tmp$_4.put_xwzc9p$(tmp$_3, value);
    };
  }));
  KVServiceManager.prototype.bind_ipz4ww$ = defineInlineFunction('kvision-kvision-server-ktor-jsLegacy.io.kvision.remote.KVServiceManager.bind_ipz4ww$', wrapFunction(function () {
    var HttpMethod = _.$$importsForInline$$['kvision-kvision-common-remote-jsLegacy'].io.kvision.remote.HttpMethod;
    var UnsupportedOperationException_init = Kotlin.kotlin.UnsupportedOperationException_init_pdl1vj$;
    var toString = Kotlin.toString;
    var Pair_init = Kotlin.kotlin.Pair;
    var KFunction = Kotlin.kotlin.reflect.KFunction;
    var Regex_init = Kotlin.kotlin.text.Regex_init_61zpoe$;
    return function (PAR_0, isPAR, RET_0, isRET, function_0, method, route) {
      if (method === void 0)
        method = HttpMethod.POST;
      if (route === void 0)
        route = null;
      var tmp$, tmp$_0, tmp$_1, tmp$_2, tmp$_3, tmp$_4;
      if (method === HttpMethod.GET)
        throw UnsupportedOperationException_init('GET method is only supported for methods without parameters');
      var routeDef = route != null ? route : 'route' + toString(Kotlin.getKClassFromExpression(this).simpleName) + (tmp$ = this.counter, this.counter = tmp$ + 1 | 0, tmp$);
      tmp$_4 = this.calls;
      var tmp$_5;
      if ((tmp$_2 = (tmp$_1 = Kotlin.isType(tmp$_0 = function_0, KFunction) ? tmp$_0 : null) != null ? tmp$_1.callableName : null) != null)
        tmp$_5 = tmp$_2;
      else {
        var tmp$_6 = function_0.toString();
        tmp$_5 = Regex_init('\\s').replace_x2uqeu$(tmp$_6, '');
      }
      tmp$_3 = tmp$_5;
      var value = new Pair_init('/kv/' + routeDef, method);
      tmp$_4.put_xwzc9p$(tmp$_3, value);
    };
  }));
  KVServiceManager.prototype.bind_dbvvzg$ = defineInlineFunction('kvision-kvision-server-ktor-jsLegacy.io.kvision.remote.KVServiceManager.bind_dbvvzg$', wrapFunction(function () {
    var HttpMethod = _.$$importsForInline$$['kvision-kvision-common-remote-jsLegacy'].io.kvision.remote.HttpMethod;
    var UnsupportedOperationException_init = Kotlin.kotlin.UnsupportedOperationException_init_pdl1vj$;
    var toString = Kotlin.toString;
    var Pair_init = Kotlin.kotlin.Pair;
    var KFunction = Kotlin.kotlin.reflect.KFunction;
    var Regex_init = Kotlin.kotlin.text.Regex_init_61zpoe$;
    return function (PAR1_0, isPAR1, PAR2_0, isPAR2, RET_0, isRET, function_0, method, route) {
      if (method === void 0)
        method = HttpMethod.POST;
      if (route === void 0)
        route = null;
      var tmp$, tmp$_0, tmp$_1, tmp$_2, tmp$_3, tmp$_4;
      if (method === HttpMethod.GET)
        throw UnsupportedOperationException_init('GET method is only supported for methods without parameters');
      var routeDef = route != null ? route : 'route' + toString(Kotlin.getKClassFromExpression(this).simpleName) + (tmp$ = this.counter, this.counter = tmp$ + 1 | 0, tmp$);
      tmp$_4 = this.calls;
      var tmp$_5;
      if ((tmp$_2 = (tmp$_1 = Kotlin.isType(tmp$_0 = function_0, KFunction) ? tmp$_0 : null) != null ? tmp$_1.callableName : null) != null)
        tmp$_5 = tmp$_2;
      else {
        var tmp$_6 = function_0.toString();
        tmp$_5 = Regex_init('\\s').replace_x2uqeu$(tmp$_6, '');
      }
      tmp$_3 = tmp$_5;
      var value = new Pair_init('/kv/' + routeDef, method);
      tmp$_4.put_xwzc9p$(tmp$_3, value);
    };
  }));
  KVServiceManager.prototype.bind_9d2ee$ = defineInlineFunction('kvision-kvision-server-ktor-jsLegacy.io.kvision.remote.KVServiceManager.bind_9d2ee$', wrapFunction(function () {
    var HttpMethod = _.$$importsForInline$$['kvision-kvision-common-remote-jsLegacy'].io.kvision.remote.HttpMethod;
    var UnsupportedOperationException_init = Kotlin.kotlin.UnsupportedOperationException_init_pdl1vj$;
    var toString = Kotlin.toString;
    var Pair_init = Kotlin.kotlin.Pair;
    var KFunction = Kotlin.kotlin.reflect.KFunction;
    var Regex_init = Kotlin.kotlin.text.Regex_init_61zpoe$;
    return function (PAR1_0, isPAR1, PAR2_0, isPAR2, PAR3_0, isPAR3, RET_0, isRET, function_0, method, route) {
      if (method === void 0)
        method = HttpMethod.POST;
      if (route === void 0)
        route = null;
      var tmp$, tmp$_0, tmp$_1, tmp$_2, tmp$_3, tmp$_4;
      if (method === HttpMethod.GET)
        throw UnsupportedOperationException_init('GET method is only supported for methods without parameters');
      var routeDef = route != null ? route : 'route' + toString(Kotlin.getKClassFromExpression(this).simpleName) + (tmp$ = this.counter, this.counter = tmp$ + 1 | 0, tmp$);
      tmp$_4 = this.calls;
      var tmp$_5;
      if ((tmp$_2 = (tmp$_1 = Kotlin.isType(tmp$_0 = function_0, KFunction) ? tmp$_0 : null) != null ? tmp$_1.callableName : null) != null)
        tmp$_5 = tmp$_2;
      else {
        var tmp$_6 = function_0.toString();
        tmp$_5 = Regex_init('\\s').replace_x2uqeu$(tmp$_6, '');
      }
      tmp$_3 = tmp$_5;
      var value = new Pair_init('/kv/' + routeDef, method);
      tmp$_4.put_xwzc9p$(tmp$_3, value);
    };
  }));
  KVServiceManager.prototype.bind_oib1c4$ = defineInlineFunction('kvision-kvision-server-ktor-jsLegacy.io.kvision.remote.KVServiceManager.bind_oib1c4$', wrapFunction(function () {
    var HttpMethod = _.$$importsForInline$$['kvision-kvision-common-remote-jsLegacy'].io.kvision.remote.HttpMethod;
    var UnsupportedOperationException_init = Kotlin.kotlin.UnsupportedOperationException_init_pdl1vj$;
    var toString = Kotlin.toString;
    var Pair_init = Kotlin.kotlin.Pair;
    var KFunction = Kotlin.kotlin.reflect.KFunction;
    var Regex_init = Kotlin.kotlin.text.Regex_init_61zpoe$;
    return function (PAR1_0, isPAR1, PAR2_0, isPAR2, PAR3_0, isPAR3, PAR4_0, isPAR4, RET_0, isRET, function_0, method, route) {
      if (method === void 0)
        method = HttpMethod.POST;
      if (route === void 0)
        route = null;
      var tmp$, tmp$_0, tmp$_1, tmp$_2, tmp$_3, tmp$_4;
      if (method === HttpMethod.GET)
        throw UnsupportedOperationException_init('GET method is only supported for methods without parameters');
      var routeDef = route != null ? route : 'route' + toString(Kotlin.getKClassFromExpression(this).simpleName) + (tmp$ = this.counter, this.counter = tmp$ + 1 | 0, tmp$);
      tmp$_4 = this.calls;
      var tmp$_5;
      if ((tmp$_2 = (tmp$_1 = Kotlin.isType(tmp$_0 = function_0, KFunction) ? tmp$_0 : null) != null ? tmp$_1.callableName : null) != null)
        tmp$_5 = tmp$_2;
      else {
        var tmp$_6 = function_0.toString();
        tmp$_5 = Regex_init('\\s').replace_x2uqeu$(tmp$_6, '');
      }
      tmp$_3 = tmp$_5;
      var value = new Pair_init('/kv/' + routeDef, method);
      tmp$_4.put_xwzc9p$(tmp$_3, value);
    };
  }));
  KVServiceManager.prototype.bind_ww2crs$ = defineInlineFunction('kvision-kvision-server-ktor-jsLegacy.io.kvision.remote.KVServiceManager.bind_ww2crs$', wrapFunction(function () {
    var HttpMethod = _.$$importsForInline$$['kvision-kvision-common-remote-jsLegacy'].io.kvision.remote.HttpMethod;
    var UnsupportedOperationException_init = Kotlin.kotlin.UnsupportedOperationException_init_pdl1vj$;
    var toString = Kotlin.toString;
    var Pair_init = Kotlin.kotlin.Pair;
    var KFunction = Kotlin.kotlin.reflect.KFunction;
    var Regex_init = Kotlin.kotlin.text.Regex_init_61zpoe$;
    return function (PAR1_0, isPAR1, PAR2_0, isPAR2, PAR3_0, isPAR3, PAR4_0, isPAR4, PAR5_0, isPAR5, RET_0, isRET, function_0, method, route) {
      if (method === void 0)
        method = HttpMethod.POST;
      if (route === void 0)
        route = null;
      var tmp$, tmp$_0, tmp$_1, tmp$_2, tmp$_3, tmp$_4;
      if (method === HttpMethod.GET)
        throw UnsupportedOperationException_init('GET method is only supported for methods without parameters');
      var routeDef = route != null ? route : 'route' + toString(Kotlin.getKClassFromExpression(this).simpleName) + (tmp$ = this.counter, this.counter = tmp$ + 1 | 0, tmp$);
      tmp$_4 = this.calls;
      var tmp$_5;
      if ((tmp$_2 = (tmp$_1 = Kotlin.isType(tmp$_0 = function_0, KFunction) ? tmp$_0 : null) != null ? tmp$_1.callableName : null) != null)
        tmp$_5 = tmp$_2;
      else {
        var tmp$_6 = function_0.toString();
        tmp$_5 = Regex_init('\\s').replace_x2uqeu$(tmp$_6, '');
      }
      tmp$_3 = tmp$_5;
      var value = new Pair_init('/kv/' + routeDef, method);
      tmp$_4.put_xwzc9p$(tmp$_3, value);
    };
  }));
  KVServiceManager.prototype.bind_9s8xgg$ = defineInlineFunction('kvision-kvision-server-ktor-jsLegacy.io.kvision.remote.KVServiceManager.bind_9s8xgg$', wrapFunction(function () {
    var HttpMethod = _.$$importsForInline$$['kvision-kvision-common-remote-jsLegacy'].io.kvision.remote.HttpMethod;
    var UnsupportedOperationException_init = Kotlin.kotlin.UnsupportedOperationException_init_pdl1vj$;
    var toString = Kotlin.toString;
    var Pair_init = Kotlin.kotlin.Pair;
    var KFunction = Kotlin.kotlin.reflect.KFunction;
    var Regex_init = Kotlin.kotlin.text.Regex_init_61zpoe$;
    return function (PAR1_0, isPAR1, PAR2_0, isPAR2, PAR3_0, isPAR3, PAR4_0, isPAR4, PAR5_0, isPAR5, PAR6_0, isPAR6, RET_0, isRET, function_0, method, route) {
      if (method === void 0)
        method = HttpMethod.POST;
      if (route === void 0)
        route = null;
      var tmp$, tmp$_0, tmp$_1, tmp$_2, tmp$_3, tmp$_4;
      if (method === HttpMethod.GET)
        throw UnsupportedOperationException_init('GET method is only supported for methods without parameters');
      var routeDef = route != null ? route : 'route' + toString(Kotlin.getKClassFromExpression(this).simpleName) + (tmp$ = this.counter, this.counter = tmp$ + 1 | 0, tmp$);
      tmp$_4 = this.calls;
      var tmp$_5;
      if ((tmp$_2 = (tmp$_1 = Kotlin.isType(tmp$_0 = function_0, KFunction) ? tmp$_0 : null) != null ? tmp$_1.callableName : null) != null)
        tmp$_5 = tmp$_2;
      else {
        var tmp$_6 = function_0.toString();
        tmp$_5 = Regex_init('\\s').replace_x2uqeu$(tmp$_6, '');
      }
      tmp$_3 = tmp$_5;
      var value = new Pair_init('/kv/' + routeDef, method);
      tmp$_4.put_xwzc9p$(tmp$_3, value);
    };
  }));
  KVServiceManager.prototype.bindTabulatorRemote_8e5sxh$ = defineInlineFunction('kvision-kvision-server-ktor-jsLegacy.io.kvision.remote.KVServiceManager.bindTabulatorRemote_8e5sxh$', wrapFunction(function () {
    var toString = Kotlin.toString;
    var HttpMethod = _.$$importsForInline$$['kvision-kvision-common-remote-jsLegacy'].io.kvision.remote.HttpMethod;
    var Pair_init = Kotlin.kotlin.Pair;
    var KFunction = Kotlin.kotlin.reflect.KFunction;
    var Regex_init = Kotlin.kotlin.text.Regex_init_61zpoe$;
    return function (RET_0, isRET, function_0, route) {
      if (route === void 0)
        route = null;
      var tmp$, tmp$_0, tmp$_1, tmp$_2, tmp$_3, tmp$_4;
      var routeDef = route != null ? route : 'route' + toString(Kotlin.getKClassFromExpression(this).simpleName) + (tmp$ = this.counter, this.counter = tmp$ + 1 | 0, tmp$);
      tmp$_4 = this.calls;
      var tmp$_5;
      if ((tmp$_2 = (tmp$_1 = Kotlin.isType(tmp$_0 = function_0, KFunction) ? tmp$_0 : null) != null ? tmp$_1.callableName : null) != null)
        tmp$_5 = tmp$_2;
      else {
        var tmp$_6 = function_0.toString();
        tmp$_5 = Regex_init('\\s').replace_x2uqeu$(tmp$_6, '');
      }
      tmp$_3 = tmp$_5;
      var value = new Pair_init('/kv/' + routeDef, HttpMethod.POST);
      tmp$_4.put_xwzc9p$(tmp$_3, value);
    };
  }));
  KVServiceManager.prototype.bind_j9amng$ = defineInlineFunction('kvision-kvision-server-ktor-jsLegacy.io.kvision.remote.KVServiceManager.bind_j9amng$', wrapFunction(function () {
    var toString = Kotlin.toString;
    var HttpMethod = _.$$importsForInline$$['kvision-kvision-common-remote-jsLegacy'].io.kvision.remote.HttpMethod;
    var Pair_init = Kotlin.kotlin.Pair;
    var KFunction = Kotlin.kotlin.reflect.KFunction;
    var Regex_init = Kotlin.kotlin.text.Regex_init_61zpoe$;
    return function (PAR1_0, isPAR1, PAR2_0, isPAR2, function_0, route) {
      if (route === void 0)
        route = null;
      var tmp$, tmp$_0, tmp$_1, tmp$_2, tmp$_3, tmp$_4;
      var routeDef = route != null ? route : 'route' + toString(Kotlin.getKClassFromExpression(this).simpleName) + (tmp$ = this.counter, this.counter = tmp$ + 1 | 0, tmp$);
      tmp$_4 = this.calls;
      var tmp$_5;
      if ((tmp$_2 = (tmp$_1 = Kotlin.isType(tmp$_0 = function_0, KFunction) ? tmp$_0 : null) != null ? tmp$_1.callableName : null) != null)
        tmp$_5 = tmp$_2;
      else {
        var tmp$_6 = function_0.toString();
        tmp$_5 = Regex_init('\\s').replace_x2uqeu$(tmp$_6, '');
      }
      tmp$_3 = tmp$_5;
      var value = new Pair_init('/kvws/' + routeDef, HttpMethod.POST);
      tmp$_4.put_xwzc9p$(tmp$_3, value);
    };
  }));
  KVServiceManager.prototype.getCalls = function () {
    return this.calls;
  };
  KVServiceManager.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'KVServiceManager',
    interfaces: [KVServiceMgr]
  };
  $$importsForInline$$['kvision-kvision-common-remote-jsLegacy'] = $module$kvision_kvision_common_remote_jsLegacy;
  var package$io = _.io || (_.io = {});
  var package$kvision = package$io.kvision || (package$io.kvision = {});
  var package$remote = package$kvision.remote || (package$kvision.remote = {});
  package$remote.KVServiceManager = KVServiceManager;
  Kotlin.defineModule('kvision-kvision-server-ktor-jsLegacy', _);
  return _;
}));

==> kvision-server-ktor-js-4.4.0.jar: kvision-kvision-server-ktor-jsLegacy.js <==
(function (root, factory) {
  if (typeof define === 'function' && define.amd)
    define(['exports', 'kotlin', 'kvision-kvision-common-remote-jsLegacy'], factory);
  else if (typeof exports === 'object')
    factory(module.exports, require('kotlin'), require('kvision-kvision-common-remote-jsLegacy'));
  else {
    if (typeof kotlin === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-server-ktor-jsLegacy'. Its dependency 'kotlin' was not found. Please, check whether 'kotlin' is loaded prior to 'kvision-kvision-server-ktor-jsLegacy'.");
    }if (typeof this['kvision-kvision-common-remote-jsLegacy'] === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-server-ktor-jsLegacy'. Its dependency 'kvision-kvision-common-remote-jsLegacy' was not found. Please, check whether 'kvision-kvision-common-remote-jsLegacy' is loaded prior to 'kvision-kvision-server-ktor-jsLegacy'.");
    }root['kvision-kvision-server-ktor-jsLegacy'] = factory(typeof this['kvision-kvision-server-ktor-jsLegacy'] === 'undefined' ? {} : this['kvision-kvision-server-ktor-jsLegacy'], kotlin, this['kvision-kvision-common-remote-jsLegacy']);
  }
}(this, function (_, Kotlin, $module$kvision_kvision_common_remote_jsLegacy) {
  'use strict';
  var KVServiceManagerJs = $module$kvision_kvision_common_remote_jsLegacy.io.kvision.remote.KVServiceManagerJs;
  var Kind_CLASS = Kotlin.Kind.CLASS;
  var KVServiceMgr = $module$kvision_kvision_common_remote_jsLegacy.io.kvision.remote.KVServiceMgr;
  KVServiceManager.prototype = Object.create(KVServiceManagerJs.prototype);
  KVServiceManager.prototype.constructor = KVServiceManager;
  function KVServiceManager(serviceClass) {
    KVServiceManagerJs.call(this);
  }
  KVServiceManager.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'KVServiceManager',
    interfaces: [KVServiceManagerJs, KVServiceMgr]
  };
  var package$io = _.io || (_.io = {});
  var package$kvision = package$io.kvision || (package$io.kvision = {});
  var package$remote = package$kvision.remote || (package$kvision.remote = {});
  package$remote.KVServiceManager = KVServiceManager;
  Kotlin.defineModule('kvision-kvision-server-ktor-jsLegacy', _);
  return _;
}));
